@@ -2,7 +2,7 @@ package OpenGuides::Template;
 
 use strict;
 use vars qw( $VERSION );
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 use Carp qw( croak );
 use CGI; # want to get rid of this and put the burden on the templates
@@ -104,8 +104,7 @@ sub output {
     croak "No template supplied" unless $args{template};
     my $config = $args{config} or croak "No config supplied";
     my $template_path = $config->{_}->{template_path};
-    my $tt = Template->new( { POST_CHOMP   => 1,
-                              INCLUDE_PATH => $template_path } );
+    my $tt = Template->new( { INCLUDE_PATH => $template_path } );
 
     my $script_name = $config->{_}->{script_name};
     my $script_url  = $config->{_}->{script_url};
